<?php

App::uses('BuzzStaffRotasAppController', 'BuzzStaffRotas.Controller');

class StaffRotasController extends BuzzStaffRotasAppController {

	public function beforeFilter() {
		parent::beforeFilter();
		$this->Auth->allow(['index', 'rota', 'generateUrl']);
	}

	/**
	 * No controller logic needed
	 * @return null
	 */
	public function index() { }

	public function rota($date, $department = null, $user = null) {
		$Model = $this->{$this->modelClass};
		$alias = $Model->alias;

		// Set the variables in the view in case they update the date filter.
		$this->set(compact('date', 'department', 'user'));
		// build the base URL; a date is always required.
		$url = $alias::API_URL . $alias::DATE_PREPEND . $date;

		if (!is_null($department)) {
			// if department is used, format it and append.
			$department = urlencode($department);
			$url .= $alias::DEPARTMENT_PREPEND . $department;
		}

		if (!is_null($user)) {
			// if username is used, format it and append.
			$user = urlencode($user);
			$url .= $alias::USERNAME_PREPEND . $user;
		}

		// Go grab data from Twinwoods API.
		$encodedData = file_get_contents($url);
		if ($encodedData === false) {
			throw new NotFoundException;
		}
		$data = json_decode($encodedData);

		// Order the array of objects based on name attribute of each object.
		usort($data->d, function ($a, $b) {
			return ($a->WorkedByUser > $b->WorkedByUser);
		});
		$this->set('data', $data->d);
	}

	/**
	 * Forms are submitted to this function. This then handles the data
	 * and builds the URL, which the user is redirected to.
	 * @return redirect array
	 */
	public function generateUrl() {
		$filters = $this->request->data['filter'];
		if (isset($filters['Date']) && !empty($filters['Date'])) {
			// Build the date in the right format.
			$date = $filters['Date']['year'];
			$date .= "-" . $filters['Date']['month'];
			$date .= "-" . $filters['Date']['day'];
		} else {
			$date = '';
		}
		if (isset($filters['Department']) && !empty($filters['Department'])) {
			$department = strtolower($filters['Department']);
		} else {
			$department = '';
		}
		if (isset($filters['Username']) && !empty($filters['Username'])) {
			$username = strtolower($filters['Username']);
		} else {
			$username = '';
		}
		return $this->redirect(
			[
				'action' => 'rota',
				$date,
				$department,
				$username
			]
		);
	}

}
